core/async_pod library

Classes

AsyncPod<T>
An extended WhalePod dedicated to managing asynchronous state. This tracks whether a network request or heavy operation is loading, successful, or failed, enabling the obx pattern from GetX.

Enums

AsyncStatus

Extensions

AsyncPodExt on T
Extension for creating AsyncPod immediately from any type or value.