core/devtools library

Classes

WhaleDevTools
State DevTools for the Blue Whale framework! This tracks exactly which widgets are rebuilding and why. Toggle WhaleDevTools.enabled to view the timeline execution graph in the console.