WhaleDevTools class

State DevTools for the Blue Whale framework! This tracks exactly which widgets are rebuilding and why. Toggle WhaleDevTools.enabled to view the timeline execution graph in the console.

Constructors

WhaleDevTools()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enabled bool
getter/setter pair

Static Methods

logMutation(WhalePod pod, dynamic oldValue, dynamic newValue) → void
logRebuild(Widget widget, Set<WhalePod> pods) → void