WhaleStorage class
Manage automatic storage syncing for persistentState.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isInitialized → bool
-
no setter
- prefs → SharedPreferences
-
no setter
Static Methods
-
clearAll(
) → Future< void> - Clear all data stored by WhaleStorage in SharedPreferences.
-
init(
) → Future< void> -
Initializes the local persistence engine (SharedPreferences).
Required before accessing persistentState.
E.g.,
await WhaleStorage.init();early inmain().