PodTracker class

State tracker for discovering reactive variables implicitly.

Constructors

PodTracker()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

currentListener ↔ WhalePodListener?
getter/setter pair
isBatching → bool
no setter

Static Methods

endBatch() → void
endTrackingReads() → Set<WhalePod>
queueBatchedNotification(WhalePod pod) → void
reportRead(WhalePod pod) → void
Register a read to wire up contextual scopes or derivations.
startBatch() → void
startTrackingReads() → void