reportRead static method
Register a read to wire up contextual scopes or derivations.
Implementation
static void reportRead(WhalePod pod) {
currentListener?.listenTo(pod);
if (_trackerStack.isNotEmpty) {
_trackerStack.last.add(pod);
}
}
Register a read to wire up contextual scopes or derivations.
static void reportRead(WhalePod pod) {
currentListener?.listenTo(pod);
if (_trackerStack.isNotEmpty) {
_trackerStack.last.add(pod);
}
}