derive<T> function

WhalePod<T> derive<T>(
  1. T compute()
)

A computed state that derives its value from other reactive states. It automatically tracks dependencies and updates when they change.

Implementation

WhalePod<T> derive<T>(T Function() compute) {
  return DerivedPod<T>(compute);
}