setup property
A builder where you can register dependencies specific to this scope.
E.g. setup: (scope) => scope.put(LoginController())
Implementation
final void Function(WhaleScopeRegistry scope)? setup;
A builder where you can register dependencies specific to this scope.
E.g. setup: (scope) => scope.put(LoginController())
final void Function(WhaleScopeRegistry scope)? setup;