WhaleScopeRegistry class
Registry passed to WhaleScope.setup that tracks all allocations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disposeAll(
) → void - Cleans up all tracked dependencies from the global Reef.
-
lazyPut<
T extends Object> (T builder(), {String? tag}) → void - Injects a lazily evaluated dependency and tracks it for scoped cleanup.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put<
T extends Object> (T dependency, {String? tag}) → void - Injects a dependency synchronously and tracks it for scoped cleanup.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited