menu
blue_whale package
documentation
core/devtools.dart
core/devtools.dart
dark_mode
light_mode
core/devtools
library
Classes
WhaleDevTools
State DevTools for the Blue Whale framework! This tracks exactly which widgets are rebuilding and why. Toggle
WhaleDevTools.enabled
to view the timeline execution graph in the console.
blue_whale package
documentation
core/devtools.dart
blue_whale
package
Libraries
blue_whale
blue_whale_facade
core/async_pod
core/current
core/devtools
core/persistent
core/pod
core/pod_extensions
core/reactive
core/reef
core/scope
core/surface
core/tank
core/workers
internationalization/whale_locale_pod
internationalization/whale_string_extensions
internationalization/whale_translations
navigation/whale_navigator
navigation/whale_route
navigation/whale_route_aware_tank
utils/blue_whale_di
utils/whale_overlays
whale
widgets/pod_builder
widgets/whale_app
widgets/whale_builder
widgets/whale_stream_builder
devtools library