derive<T> function
A computed state that derives its value from other reactive states. It automatically tracks dependencies and updates when they change.
Implementation
WhalePod<T> derive<T>(T Function() compute) {
return DerivedPod<T>(compute);
}