core/scope library
Classes
- WhaleScope
- A scoped dependency injection container for Blue Whale. Dependencies registered in this scope will be automatically destroyed and removed from memory when this widget is removed from the widget tree (e.g., navigating away).
- WhaleScopeRegistry
- Registry passed to WhaleScope.setup that tracks all allocations.