WhaleTank class abstract
WhaleTank: A container for business logic, managing one or more WhalePods.
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
no setter
- isInitialized → bool
-
no setter
- isReady → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
override
-
markClosed(
) → void - Public method to allow Reef to mark the tank as closed before disposal.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void -
onInit(
) → void -
onReady(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited