utils/blue_whale_di
library
Functions
-
delete<T extends Object>({String? tag, bool permanent = true})
→ bool
-
Convenience function to delete a dependency from the global Reef.
Same as
Reef.i.delete<T>().
-
factory<T extends Object>(T factory(), {String? tag, bool override = false})
→ void
-
Convenience function to register a factory into the global Reef.
Same as
Reef.i.factory<T>().
-
lazyPut<T extends Object>(T factory(), {String? tag, bool override = false})
→ void
-
Convenience function to lazily put a dependency into the global Reef.
Same as
Reef.i.lazyPut<T>().
-
put<T extends Object>(T instance, {String? tag, bool override = false})
→ void
-
Convenience function to put a dependency into the global Reef.
Same as
Reef.i.put<T>().
-
use<T extends Object>({String? tag})
→ T
-
Convenience function to find a dependency from the global Reef.
Same as
Reef.i.find<T>().