Whale class
'Whale' is the absolute simplest way to call Blue Whale features. It works just like GetX's 'Get' class.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- arguments → WhaleRouteArguments?
-
Get the arguments passed to the current route.
no setter
- currentRouteName → String?
-
Get the current route name.
no setter
Static Methods
-
back<
T extends Object?> ({T? result}) → void - Navigate back to the previous route.
-
delete<
T extends Object> ({String? tag, bool permanent = true}) → bool - Remove an instance from the dependency container.
-
enableDevTools(
) → void - Enable deep diagnostic logging for Blue Whale. This will log all state mutations and UI rebuilds to the console.
-
find<
T extends Object> ({String? tag}) → T - Find an instance from the dependency container.
-
lazyPut<
T extends Object> (T factory(), {String? tag, bool override = false}) → void - Lazily register a factory into the dependency container.
-
off<
T extends Object?, TO extends Object?> (String routeName, {dynamic arguments, TO? result}) → Future< T?> ? - Replace the current route.
-
offAll<
T extends Object?> (String routeName, {dynamic arguments}) → Future< T?> ? - Clear all previous routes and navigate to a new one.
-
put<
T extends Object> (T instance, {String? tag, bool override = false}) → void - Register an instance into the dependency container.
-
showBottomSheet<
T> ({required WidgetBuilder builder, Color? backgroundColor}) → Future< T?> - Show a bottom sheet.
-
showDialog<
T> ({required WidgetBuilder builder, bool barrierDismissible = true}) → Future< T?> - Show a simple dialog.
-
showSnackbar(
String message, {Duration duration = const Duration(seconds: 4)}) → void - Show a snackbar quickly.
-
to<
T extends Object?> (String routeName, {dynamic arguments}) → Future< T?> ? - Navigate to a new route.